#!/usr/bin/env python3
"""
WSGI entry point for production deployment
"""
import os
import sys
from pathlib import Path

# Add the project directory to the Python path
project_root = Path(__file__).parent.absolute()
sys.path.insert(0, str(project_root))

# Set production environment
os.environ['FLASK_ENV'] = 'production'

# Import and configure the Flask app
from app import app

# Production configuration overrides
app.config.update(
    DEBUG=False,
    TESTING=False,
    # Ensure proper secret key is set in production
    SECRET_KEY=os.environ.get('SECRET_KEY', app.config.get('SECRET_KEY'))
)

# Create the WSGI application
application = app

if __name__ == '__main__':
    # This is only for development/testing
    # In production, use: gunicorn wsgi:application
    print("Warning: Running WSGI directly. Use a proper WSGI server in production!")
    application.run(host='0.0.0.0', port=5005)